@@ -16,12 +16,16 @@ safetruncate <- function(flatfile, right, left){
   # would we drop Sample.Labels?
   if(length(fsl) != length(sl)){
     # if so, get the ones we would drop
-    sl_diff <- setdiff(sl, unique(flatfile$Sample.Label[find]))
+    sl_diff <- setdiff(sl, fsl)
     # add them to the keep list
     find[flatfile$Sample.Label %in% sl_diff] <- TRUE
     # set the observation-specific data to NA
     flatfile[flatfile$Sample.Label %in% sl_diff, ]$distance <- NA
-    flatfile[flatfile$Sample.Label %in% sl_diff, ]$object <- NA
+
+    # if size or object columns are present set their values to NA
+    if(!is.null(flatfile$object)){
+      flatfile[flatfile$Sample.Label %in% sl_diff, ]$object <- NA
+    }
     if(!is.null(flatfile$size)){
       flatfile[flatfile$Sample.Label %in% sl_diff, ]$size <- NA
     }
